@@ -5,7 +5,6 @@ gi.require_version("GtkSource", "5")
 from gi.repository import Adw, Gio, GLib, GObject, Gtk, GtkSource, Pango
 
 import logging
-import re
 
 from iotas.category_header_bar import CategoryHeaderBar
 from iotas.category_treeview_list_store import CategoryTreeViewListStore
@@ -26,13 +25,7 @@ class Editor(Gtk.Box):
         "exit": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
-    LIST_TOKENS = {
-        "- [ ] ": "- [ ] ",
-        "- [x] ": "- [ ] ",
-        "- ": "- ",
-        "+ ": "+ ",
-        "* ": "* ",
-    }
+    LINE_LENGTH_STEP = 50
 
     _title_button = Gtk.Template.Child()
     _main_header_bar = Gtk.Template.Child()
@@ -64,7 +57,8 @@ class Editor(Gtk.Box):
         self.__active = False
 
         self._menu_button.get_popover().add_child(ThemeSelector(), "theme")
-        self._menu_button.get_popover().add_child(FontSizeSelector(), "fontsize")
+        self.__font_size_selector = FontSizeSelector()
+        self._menu_button.get_popover().add_child(self.__font_size_selector, "fontsize")
 
         # Retain whether markdown is enabled for the session. At the time of writing instantiating
         # WebKit after startup was crashing, so we wait until restart to change the behaviour.
@@ -87,6 +81,8 @@ class Editor(Gtk.Box):
         style_manager = Adw.StyleManager.get_default()
         style_manager.connect("notify::dark", self.__on_dark_style_updated)
 
+        iotas.config_manager.settings.connect("changed::line-length", self.__on_line_length_changed)
+
     def setup(self, model: CategoryTreeViewListStore) -> None:
         """Perform initial setup.
 
@@ -95,6 +91,8 @@ class Editor(Gtk.Box):
         self.__setup_actions()
         self._category_header_bar.setup(model)
         self._search_header_bar.setup(self._sourceview)
+        self.__font_size_selector.setup()
+        self.__refresh_line_length_from_setting()
 
     def init_note(self, note) -> None:
         """Initialise editing session.
@@ -295,6 +293,16 @@ class Editor(Gtk.Box):
         action.connect("activate", self.__on_delete_note)
         action_group.add_action(action)
 
+        action = Gio.SimpleAction.new("increase-line-length")
+        action.connect("activate", self.__on_increase_line_length)
+        action_group.add_action(action)
+        app.set_accels_for_action("editor.increase-line-length", ["<Control>Up"])
+
+        action = Gio.SimpleAction.new("decrease-line-length")
+        action.connect("activate", self.__on_decrease_line_length)
+        action_group.add_action(action)
+        app.set_accels_for_action("editor.decrease-line-length", ["<Control>Down"])
+
         self.__action_group = action_group
         app.get_active_window().insert_action_group("editor", action_group)
 
@@ -316,9 +324,6 @@ class Editor(Gtk.Box):
         if self.__updating_from_remote:
             return
 
-        if length == 1 and char == "\n":
-            self.__process_newline(location)
-
     def __on_checkbox_toggled(self, _obj: GObject.Object, line: int, new_value: bool) -> None:
         buffer = self._sourceview.get_buffer()
 
@@ -396,6 +401,21 @@ class Editor(Gtk.Box):
     def __on_delete_note(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
         self.emit("note-deleted", self.__note)
 
+    def __on_line_length_changed(self, _settings: Gio.Settings, _key: str) -> None:
+        length = iotas.config_manager.get_line_length()
+        logging.debug(f"Line length changed to {length}px")
+        self.__refresh_line_length_from_setting()
+
+    def __on_increase_line_length(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        length = iotas.config_manager.get_line_length() + self.LINE_LENGTH_STEP
+        if length < self.get_width():
+            iotas.config_manager.set_line_length(length)
+
+    def __on_decrease_line_length(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        length = iotas.config_manager.get_line_length() - self.LINE_LENGTH_STEP
+        if length >= self.LINE_LENGTH_STEP:
+            iotas.config_manager.set_line_length(length)
+
     def __on_note_update_from_sync(
         self,
         _obj: GObject.Object,
@@ -479,36 +499,6 @@ class Editor(Gtk.Box):
             self.__updating_from_remote = False
             self.set_sensitive(True)
 
-    def __line_is_list_item(self, searchterm: str) -> re.Match:
-        term = r"^\s*("
-        escaped_tokens = []
-        for token in self.LIST_TOKENS.keys():
-            escaped_tokens.append(re.escape(token))
-        term += "|".join(escaped_tokens)
-        term += ")"
-        return re.search(term, searchterm)
-
-    def __process_newline(self, location: Gtk.TextIter) -> None:
-        line_start = location.copy()
-        line_start.backward_line()
-        line_start.set_line_offset(0)
-        prev_line = line_start.get_text(location)
-
-        res = self.__line_is_list_item(prev_line)
-        if res:
-            buffer = self._sourceview.get_buffer()
-            empty_list_line = Editor.inserted_empty_item_at_end_of_list(
-                line_start, prev_line, res.group()
-            )
-            if not empty_list_line:
-                dict_key = res.group().lstrip()
-                spacing = res.group()[0 : len(res.group()) - len(dict_key)]
-                new_entry = f"{spacing}{self.LIST_TOKENS[dict_key]}"
-                buffer.insert(location, new_entry)
-            else:
-                buffer.delete(line_start, location)
-                buffer.insert_at_cursor("\n")
-
     def __get_editor_scroll_position(self) -> None:
         adj = self._editor_scrolledwin.get_vadjustment()
         value = adj.get_value()
@@ -633,17 +623,7 @@ class Editor(Gtk.Box):
         scheme = style_scheme_manager.get_scheme(scheme_id)
         buffer.set_style_scheme(scheme)
 
-    @staticmethod
-    def inserted_empty_item_at_end_of_list(
-        prev_line_start: Gtk.TextIter, prev_line: str, matched: str
-    ) -> bool:
-        # Check if prev line empty
-        if prev_line.strip() != matched.strip():
-            return False
-
-        # Check we're in a list (allows inserting lines with list start tokens and nothing else)
-        two_prev_start = prev_line_start.copy()
-        two_prev_start.backward_line()
-        two_prev_start.set_line_offset(0)
-        two_prev_line = two_prev_start.get_text(prev_line_start)
-        return two_prev_line.startswith(matched)
+    def __refresh_line_length_from_setting(self) -> None:
+        length = iotas.config_manager.get_line_length()
+        self._sourceview.set_property("maximum-width", length)
+        self._sourceview.queue_resize()
