@@ -267,6 +267,11 @@ class Index(Gtk.Box):
         action_group.add_action(action)
         app.set_accels_for_action("index.cancel", ["Escape", "<Alt>Left"])
 
+        action = Gio.SimpleAction.new("reset-filters")
+        action.connect("activate", self.__reset_filters)
+        action_group.add_action(action)
+        app.set_accels_for_action("index.reset-filters", ["<Control>BackSpace", "<Control>Delete"])
+
         action = Gio.SimpleAction.new("selection-toggle-favourite")
         action.connect("activate", self.__on_toggle_favourite)
         action_group.add_action(action)
@@ -618,7 +623,7 @@ class Index(Gtk.Box):
         if time_filtered:
             self.__note_manager.filter_older_notes_by_date()
         loaded_notes = self._note_list.populate_older_notes(
-            self.__note_manager.older_notes_model, displayed
+            self.__note_manager.older_notes_model, self.__on_listbox_key_pressed, displayed
         )
         if update_section_visibility:
             self._note_list.refresh_section_visibility(self.__category)
@@ -637,7 +642,9 @@ class Index(Gtk.Box):
         # last two months
         if older_notes_loaded:
             self.__older_notes_model = self.__note_manager.older_notes_model
-            self._note_list.populate_older_notes(self.__note_manager.older_notes_model)
+            self._note_list.populate_older_notes(
+                self.__note_manager.older_notes_model, self.__on_listbox_key_pressed
+            )
 
         self._stack.set_visible(True)
 
@@ -702,6 +709,22 @@ class Index(Gtk.Box):
 
         If searching returns to normal view.
         """
+        self.__cancel_out_of_context(False)
+
+    def __reset_filters(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        """Handle a user request to reset the index."""
+        self.__cancel_out_of_context(True)
+
+    def __cancel_out_of_context(self, including_category: bool) -> None:
+        if including_category:
+            if (
+                self.__category.special_purpose is None
+                or self.__category.special_purpose != CategorySpecialPurpose.ALL
+            ):
+                (category, _) = self.__category_manager.get_special_purpose_category(
+                    CategorySpecialPurpose.ALL
+                )
+                self.__on_category_activated(category, False)
         if self._categories_flap.get_reveal_flap():
             self.__close_sidebar()
         elif self._selection_header_bar.active:
