@@ -118,6 +118,7 @@ class IndexNoteList(Gtk.Box):
     def populate_older_notes(
         self,
         older_notes_model: NoteListModelTimeFiltered,
+        listbox_keypress_func: Callable,
         display_section: bool = True,
     ) -> bool:
         """Populate notes older than two months.
@@ -126,6 +127,7 @@ class IndexNoteList(Gtk.Box):
         two month old mark. Also used for searching.
 
         :param NoteListModelTimeFiltered older_notes_model: Model for the older notes
+        :param Callable listbox_keypress_func: Function to call on listbox keypress
         :param bool display_section: The user has requested this load action and the notes
             should be shown in the main index. If false the notes are being loaded for
             searching and won't be displayed in the main index yet (which retains performance
@@ -144,7 +146,11 @@ class IndexNoteList(Gtk.Box):
             self._older_notes_listbox.bind_model(self.__older_notes_model, self.__create_row, None)
             self.__listboxes.append(self._older_notes_listbox)
             self.__older_notes_model.connect("items-changed", self.__older_notes_items_changed)
+            controller = Gtk.EventControllerKey()
+            controller.connect("key-pressed", listbox_keypress_func)
+            self._older_notes_listbox.add_controller(controller)
             self._older_notes_listbox.connect("row-activated", self.__on_row_activated)
+            self._older_notes_listbox.connect("row-selected", self.__on_row_selected)
 
         self._older_notes_loader.set_visible(False)
         if len(self.__older_notes_model) > 0:
@@ -307,9 +313,9 @@ class IndexNoteList(Gtk.Box):
         if focused_row == top_row:
             self.__focus_previous_list_box(listbox)
         else:
-            prev_row = focused_row.get_prev_sibling()
-            listbox.select_row(prev_row)
-            prev_row.grab_focus()
+            previous_row = focused_row.get_prev_sibling()
+            listbox.select_row(previous_row)
+            previous_row.grab_focus()
 
     def restrict_for_search_by_ids(self, ids: Optional[List[int]]) -> None:
         """Restrict by identifiers while searching.
@@ -367,30 +373,30 @@ class IndexNoteList(Gtk.Box):
         )
         self._older_notes_section.set_visible(visible)
 
-    def __focus_next_list_box(self, prev_listbox: Gtk.ListBox) -> None:
+    def __focus_next_list_box(self, previous_listbox: Gtk.ListBox) -> None:
         found = False
         for listbox in self.__listboxes:
-            if not found and listbox == prev_listbox:
+            if not found and listbox == previous_listbox:
                 found = True
                 continue
             if found and listbox.get_parent().get_visible():
                 row = listbox.get_row_at_index(0)
                 row.grab_focus()
                 listbox.select_row(row)
-                prev_listbox.unselect_all()
+                previous_listbox.unselect_all()
                 break
 
-    def __focus_prevous_list_box(self, prev_listbox: Gtk.ListBox) -> None:
+    def __focus_previous_list_box(self, previous_listbox: Gtk.ListBox) -> None:
         found = False
         for listbox in reversed(self.__listboxes):
-            if not found and listbox == prev_listbox:
+            if not found and listbox == previous_listbox:
                 found = True
                 continue
             if found and listbox.get_parent().get_visible():
                 row = listbox.get_last_child()
                 row.grab_focus()
                 listbox.select_row(row)
-                prev_listbox.unselect_all()
+                previous_listbox.unselect_all()
                 break
 
     def __on_row_activated(self, listbox: Gtk.ListBox, row: Gtk.ListBoxRow) -> None:
