@@ -48,6 +48,8 @@ class SyncManager(GObject.Object):
 
     STARTUP_SYNC_INIT_DURATION = 500
     SYNC_FAIL_OFFLINE_THRESHOLD = 2
+    MIN_NEW_NOTES_FOR_BATCHING = 30
+    SYNC_BATCH_SIZE = 5
 
     def __init__(self, db: NoteDatabase):
         super().__init__()
@@ -260,8 +262,19 @@ class SyncManager(GObject.Object):
                 len(remote_del),
             )
         if changes_in > 0:
-            # Integrate remote changes
-            idle_add_wait(self.__integrate_remote_changes, remote_new, remote_upd, remote_del)
+            # Integrate remote changes, batching for large initial transfers
+            if len(remote_new) > self.MIN_NEW_NOTES_FOR_BATCHING:
+                batch_size = self.SYNC_BATCH_SIZE
+            else:
+                batch_size = self.MIN_NEW_NOTES_FOR_BATCHING
+            for i in range(0, max(1, len(remote_new)), batch_size):
+                if len(remote_new) > 0:
+                    batch = remote_new[i : i + batch_size]
+                else:
+                    batch = []
+                idle_add_wait(self.__integrate_remote_changes, batch, remote_upd, remote_del)
+                remote_upd = []
+                remote_del = []
 
         if force_refresh_all and iotas.config_manager.get_perform_full_server_refresh():
             GLib.idle_add(iotas.config_manager.set_perform_full_server_refresh, False)
